@@ -21,6 +21,7 @@ class FrogmlContainer(containers.DeclarativeContainer):
         status_for_retry=(
             grpc.StatusCode.UNAVAILABLE,
             grpc.StatusCode.CANCELLED,
+            grpc.StatusCode.DEADLINE_EXCEEDED,
         ),
     )
 
@@ -36,5 +37,8 @@ class FrogmlContainer(containers.DeclarativeContainer):
         url=config.grpc.builds.internal_address,
         enable_ssl=config.grpc.builds.enable_ssl,
         enable_auth=False,
-        status_for_retry=(grpc.StatusCode.UNAVAILABLE,),
+        status_for_retry=(
+            grpc.StatusCode.UNAVAILABLE,
+            grpc.StatusCode.DEADLINE_EXCEEDED,
+        ),
     )
