@@ -128,20 +128,19 @@ def _log_model(config: ModelLogConfig) -> None:
     properties = merge_properties_parameters_metrics(
         config.metrics, config.parameters, config.properties
     )
-    dependencies = _dependency_files_handler(
+    dependencies: list[str] = _dependency_files_handler(
         dependencies=config.dependencies, target_dir=config.target_dir
     )
     metadata = _get_model_metadata(
         config.model_framework, config.framework_version, config.serialization_format
     )
-    is_setup_template_files: bool = SetupTemplateFilesManager(
-        config=config
+    SetupTemplateFilesManager(
+        config=config, dependencies=dependencies
     ).setup_template_files()
 
     zipped_code_path: Optional[str] = build_zip_code_path(
         code_dir_path=config.code_dir,
         parent_dir_path=config.target_dir,
-        is_setup_template_files=is_setup_template_files,
     )
 
     frog_ml_model_version: FrogMLModelVersion = __log_model_to_artifactory(
@@ -169,7 +168,7 @@ def _log_model(config: ModelLogConfig) -> None:
 
 
 def build_zip_code_path(
-    code_dir_path: Optional[str], parent_dir_path: str, is_setup_template_files: bool
+    code_dir_path: Optional[str], parent_dir_path: str
 ) -> Optional[str]:
     """
     Build the path to the zipped code directory.
@@ -179,12 +178,8 @@ def build_zip_code_path(
 
     :param code_dir_path: The path to the code directory
     :param parent_dir_path: The parent directory of the zip file
-    :param is_setup_template_files: Flag indicating whether template files are set up
     :return: The path to the zipped code directory
     """
-    if not code_dir_path and not is_setup_template_files:
-        return None
-
     filtered_copied_dir_path: str = os.path.join(
         parent_dir_path, "filtered_model_files"
     )
@@ -196,11 +191,10 @@ def build_zip_code_path(
             dest_dir=filtered_copied_dir_path,
         )
 
-    if is_setup_template_files:
-        _copy_template_files(
-            template_file_dir=template_file_dir,
-            dest_dir=filtered_copied_dir_path,
-        )
+    _copy_template_files(
+        template_file_dir=template_file_dir,
+        dest_dir=filtered_copied_dir_path,
+    )
 
     try:
         # Jira Ticket: MLB-256 https://jfrog-int.atlassian.net/browse/MLB-256
